@@ -114,8 +114,7 @@ samples.fitted <- array(NA, c(n.keep, K))
     
     
 #### Metropolis quantities    
-accept.all <- rep(0,6)
-accept <- accept.all
+accept <- rep(0,6)
 proposal.sd.beta <- 0.01
 proposal.sd.phi <- 0.1
 proposal.sd.rho <- 0.02
@@ -298,8 +297,7 @@ if(rho==1) tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
         ########################################
         ## Self tune the acceptance probabilties
         ########################################
-        k <- j/100
-            if(ceiling(k)==floor(k))
+            if(ceiling(j/100)==floor(j/100) & j < burnin)
             {
             #### Update the proposal sds
                 if(p>2)
@@ -314,7 +312,6 @@ if(rho==1) tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
                 {
                 proposal.sd.rho <- common.accceptrates2(accept[5:6], proposal.sd.rho, 40, 50, 0.5)
                 }
-            accept.all <- accept.all + accept
             accept <- c(0,0,0,0,0,0)
             }else
             {}
@@ -344,11 +341,11 @@ if(rho==1) tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
 #### Summarise and save the results 
 ###################################
 ## Compute the acceptance rates
-accept.beta <- 100 * accept.all[1] / accept.all[2]
-accept.phi <- 100 * accept.all[3] / accept.all[4]
+accept.beta <- 100 * accept[1] / accept[2]
+accept.phi <- 100 * accept[3] / accept[4]
     if(!fix.rho)
     {
-    accept.rho <- 100 * accept.all[5] / accept.all[6]
+    accept.rho <- 100 * accept[5] / accept[6]
     }else
     {
     accept.rho <- NA    
