@@ -160,7 +160,6 @@ samples.fitted <- array(NA, c(n.keep, n))
     
 #### Metropolis quantities
 accept <- rep(0,2)
-accept.all <- accept
 proposal.sd.rho <- 0.02
 tau2.posterior.shape <- prior.tau2[1] + 0.5*K
 nu2.posterior.shape <- prior.nu2[1] + 0.5*n
@@ -345,15 +344,13 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     #######################################
     #### Update the acceptance rate for rho
     #######################################
-    k <- j/100
-        if(ceiling(k)==floor(k))
+        if(ceiling(j/100)==floor(j/100) & j < burnin)
         {
         #### Update the proposal sds
             if(!fix.rho)
             {
             proposal.sd.rho <- common.accceptrates2(accept[1:2], proposal.sd.rho, 40, 50, 0.5)
             }
-        accept.all <- accept.all + accept
         accept <- c(0,0)
         }else
         {}
@@ -385,14 +382,14 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
 #### Compute the acceptance rates
     if(!fix.rho)
     {
-    accept.rho <- 100 * accept.all[1] / accept.all[2]
+    accept.rho <- 100 * accept[1] / accept[2]
     }else
     {
     accept.rho <- NA    
     }
     if(!is.null(ind.re))
     {
-    accept.psi <- 100 * accept.all[7] / accept.all[8]
+    accept.psi <- 100 * accept[7] / accept[8]
     accept.sigma2 <- 100
     }else
     {
